# Generated by Django 3.2 on 2023-02-17 09:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0008_evalpreassessment_evalpreassessmenta_evalpreassessmentb'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evalpreassessmentb',
            name='scored',
            field=models.CharField(blank=True, choices=[('one', 'Demonstrated Competence at a High Level'), ('two', 'Goal Achived'), ('three', 'Goal not Reached')], max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='evalselfdeta',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdeta', to='perform.evalplanninga'),
        ),
        migrations.AlterField(
            model_name='evalselfdetb',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdetb', to='perform.evalplanningb'),
        ),
    ]



# Generated by Django 3.2 on 2023-02-17 14:02

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('custom', '0013_alter_unit_options'),
        ('employee', '0023_alter_photo_image'),
        ('perform', '0009_auto_20230217_1813'),
    ]

    operations = [
        migrations.AddField(
            model_name='eval',
            name='employeeeval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalevaluator', to='employee.employee'),
        ),
        migrations.AddField(
            model_name='eval',
            name='positioneval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalevaluator', to='custom.position'),
        ),
        migrations.AddField(
            model_name='eval',
            name='uniteval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalevaluator', to='custom.unit'),
        ),
        migrations.AlterField(
            model_name='evaldeta',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.evalplanninga'),
        ),
        migrations.AlterField(
            model_name='evaldetb',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.evalplanningb'),
        ),
    ]



# Generated by Django 3.2 on 2023-02-18 06:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0011_evalplanning_date'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalplanning',
            old_name='date',
            new_name='ind_date',
        ),
        migrations.AddField(
            model_name='evalplanning',
            name='obj_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision, Employee
from contract.models import Category, Contract, EmpPosition
from perform.models import ParameterA, ParameterB, Eval, EvalDetA, EvalDetB, EvalYear, \
EvalPlanning, EvalPlanningB, EvalType, EvalPreAssessment, EvalPreAssessmentA, EvalPreAssessmentB
from perform.forms import *
from settings_app.utils import getnewid
from settings_app.user_utils import c_staff, c_unit
from log.utils import log_action


@login_required
def PerfomConfAddPreAss(request, hashid, year):
    group = request.user.groups.all()[0].name
    employee = get_object_or_404(Employee, hashed=hashid)
    pyear = get_object_or_404(EvalYear, year=year)
    ptype = get_object_or_404(EvalType, pk=2)
    contract = Contract.objects.filter(employee=employee, is_active=True).last()
    empdiv = CurEmpDivision.objects.filter(employee=employee).last()
    newid, new_hashid = getnewid(EvalPreAssessment)
    obj = EvalPreAssessment(
        id = newid,
        hashed= new_hashid,
        year = pyear,
        type = ptype,
        is_lock = True,
        employee = employee,
        category = contract.category,
        position = contract.position,
        department = empdiv.department,
        unit = empdiv.unit
    )
    obj.save()
    objects = EvalPlanningA.objects.filter(eval__employee=employee, eval__year__year=year).all()
    objects2 = EvalPlanningB.objects.filter(eval__employee=employee, eval__year__year=year).all()
    for i in objects:
        newid, new_hashid = getnewid(EvalPreAssessmentA)
        obj2 = EvalPreAssessmentA(id=newid, eval=obj, plan_objective=i,\
            user=request.user, hashed=new_hashid)
        obj2.save()
    for j in objects2:
        newid2, new_hashid2 = getnewid(EvalPreAssessmentB)
        obj3 = EvalPreAssessmentB(id=newid2, eval=obj, parameter=j,\
            user=request.user, hashed=new_hashid2)
        obj3.save()
    messages.success(request, 'Susesu Kria Pre-Assessment Sheet')
    if group == 'hr':
        return redirect('eval-conf-dash')
    else:
        return redirect('staff-perform-list')
# @login_required
# @allowed_users(allowed_roles=['admin','hr'])
# def PerfomConfAddPreAssAll(request, year):
#     pyear = get_object_or_404(EvalYear, year=year)
#     ptype = get_object_or_404(EvalType, pk=1)
#     employees = Employee.objects.filter(status_id=1).exclude(curempdivision__de__pk=1)
#     for emp in employees:
#         check_emp_plan = EvalPlanning.objects.filter(employee=emp, year=pyear).last()
#         if not check_emp_plan:
#             contract = Contract.objects.filter(employee=emp, is_active=True).last()
#             empdiv = CurEmpDivision.objects.filter(employee=emp).last()
#             newid, new_hashid = getnewid(EvalPlanning)
#             obj = EvalPlanning(
#                 id = newid,
#                 hashed= new_hashid,
#                 year = pyear,
#                 type = ptype,
#                 employee = emp,
#                 category = contract.category,
#                 position = contract.position,
#                 department = empdiv.department,
#                 unit = empdiv.unit
#             )
#             obj.save()
#     messages.success(request, 'Susesu Kria Planning and Monitoring Sheet')
#     return redirect('eval-conf-dash')



# @login_required
# @allowed_users(allowed_roles=['admin','hr'])
# def PerfomPreAssAddObjective(request, hashid):
#     objects = get_object_or_404(EvalPlanning,hashed=hashid)
#     plan = EvalPlanningA.objects.filter(eval=objects)
#     group = request.user.groups.all()[0].name
#     if request.method == 'POST':
#             form = PlanningObjectiveForm(request.POST, instance=objects)
#             if form.is_valid():
#                  form.save()
#             messages.success(request, f'Aumeta Sucessu')
#             return redirect('eval-conf-plan-detail', hashid)
#     else: form = PlanningObjectiveForm(instance=objects)
#     context = {
#         'group': group, 'form': form, 'page': 'unit',
#         'title': 'Aumenta Objectives', 'legend': 'Aumenta Objectives'
#     }
#     return render(request, 'perform2/form.html', context)


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerfomConfPreAssDetail(request, hashid):
    objects = get_object_or_404(EvalPreAssessment,hashed=hashid)
    user = c_staff(request.user)
    check_emp = True if user == objects.employee else False
    individual = EvalPreAssessmentA.objects.filter(eval=objects)
    behavior = EvalPreAssessmentB.objects.filter(eval=objects)
    context = {
        'title': 'Detail Pre-Assessment', 'legend': 'Pre-Assessment Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior
    }
    return render(request,'perform2/pre_ass_detail.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr', 'staff', 'dep', 'unit'])
def PerfomConfPreAssAddA(request, hashid):
    group = request.user.groups.all()[0].name
    eval = get_object_or_404(EvalPreAssessment, hashed=hashid)
    objects = EvalPlanningA.objects.filter(eval__employee=eval.employee, eval__year=eval.year).all()
    for i in objects:
        newid, new_hashid = getnewid(EvalPreAssessmentA)
        obj = EvalPreAssessmentA(id=newid, eval=eval, plan_objective=i,\
            user=request.user, hashed=new_hashid)
        obj.save()
        messages.success(request, f'Importa sucessu.')
    if group == 'hr':
        return redirect('eval-conf-pre-ass-detail', hashid=hashid)
    else:
        return redirect('staff-perform-preass-detail', hashid=hashid)
         

@login_required
@allowed_users(allowed_roles=['unit','hr', 'staff', 'dep', 'unit'])
def PerfomConfPreAssAddB(request, hashid):
    group = request.user.groups.all()[0].name
    eval = get_object_or_404(EvalPreAssessment, hashed=hashid)
    objects = EvalPlanningB.objects.filter(eval__employee=eval.employee, eval__year=eval.year).all()
    for i in objects:
        newid, new_hashid = getnewid(EvalPreAssessmentB)
        obj = EvalPreAssessmentB(id=newid, eval=eval, parameter=i,\
            user=request.user, hashed=new_hashid)
        obj.save()
        messages.success(request, f'Importa sucessu.')
    if group == 'hr':
        return redirect('eval-conf-pre-ass-detail', hashid=hashid)
    else:
        return redirect('staff-perform-preass-detail', hashid=hashid)


# @login_required
# @allowed_users(allowed_roles=['admin','hr'])
# def PerfomConfPreAssAddA(request, hashid):
#     objects = get_object_or_404(EvalPreAssessmentA,hashed=hashid)
#     group = request.user.groups.all()[0].name
#     if request.method == 'POST':
#             newid, new_hashid = getnewid(EvalPreAssessmentA)
#             form = PlanningAForm(request.POST)

#             if form.is_valid():
#                  instance = form.save(commit=False)
#                  instance.id = newid
#                  instance.hashed = new_hashid
#                  instance.eval = objects
#                  instance.enter_date = datetime.date.today()
#                  instance.user = request.user
#                  instance.save()
#             messages.success(request, f'Aumeta Sucessu')
#             return redirect('eval-conf-plan-detail', hashid)
#     else: form = PlanningAForm()
#     context = {
#         'group': group, 'form': form, 'page': 'unit',
#         'title': 'Aumenta Individual Activities', 'legend': 'Aumenta Individual Activities'
#     }
#     return render(request, 'perform2/form.html', context)

# @login_required
# @allowed_users(allowed_roles=['admin','hr'])
# def PerfomPlanUdpateA(request, hashid):
#     objects = get_object_or_404(EvalPlanningA,hashed=hashid)
#     group = request.user.groups.all()[0].name
#     if request.method == 'POST':
#             form = PlanningAForm(request.POST, instance=objects)

#             if form.is_valid():
#                  instance = form.save(commit=False)
#                  instance.eval_date = datetime.date.today()
#                  instance.user = request.user
#                  instance.save()
#             messages.success(request, f'Altera Sucessu')
#             return redirect('eval-conf-plan-detail', objects.eval.hashed)
#     else: form = PlanningAForm(instance=objects)
#     context = {
#         'group': group, 'form': form, 'page': 'unit',
#         'title': 'Altera Individual Activities', 'legend': 'Altera Individual Activities'
#     }
#     return render(request, 'perform2/form.html', context)

# @login_required
# @allowed_users(allowed_roles=['admin','hr'])
# def PerfomPlanDeleteA(request, hashid, hashid2):
#     objects = get_object_or_404(EvalPlanningA,hashed=hashid)
#     plan = get_object_or_404(EvalPlanning,hashed=hashid2)
#     objects.delete()
#     messages.success(request, f'Delete Sucessu')
#     return redirect('eval-conf-plan-detail', plan.hashed)


# @login_required
# @allowed_users(allowed_roles=['admin','hr'])
# def PerfomPlanDeleteB(request, hashid, hashid2):
#     objects = get_object_or_404(EvalPlanningB,hashed=hashid)
#     plan = get_object_or_404(EvalPlanning,hashed=hashid2)
#     objects.delete()
#     messages.success(request, f'Delete Sucessu')
#     return redirect('eval-conf-plan-detail', plan.hashed)


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerfomPreAssLock(request, hashid):
    plan = get_object_or_404(EvalPreAssessment,hashed=hashid)
    plan.is_lock = True
    plan.save()
    messages.success(request, f'Chave Sucessu')
    return redirect('eval-conf-pre-ass-detail', plan.hashed)




# # EVALUATOR PRE ASS
@login_required
def PerfomEvaluatorAdd(request, hashid):
    emp, unit = c_unit(request.user)
    preass = get_object_or_404(EvalPreAssessment,hashed=hashid)
    contract = Contract.objects.filter(employee=emp, is_active=True).last()
    empdiv = CurEmpDivision.objects.filter(employee=emp).last()
    preass.employeeeval = emp
    preass.positioneval = contract.position
    preass.uniteval = empdiv.unit
    preass.save()
    messages.success(request, f'Chave Sucessu')
    return redirect('eval-pre-ass-evaluator-detail', preass.hashed)

@login_required
def PerfomEvaluatorDetail(request, hashid):
    group = request.user.groups.all()[0].name
    plan = get_object_or_404(EvalPreAssessment,hashed=hashid)
    individual = EvalPreAssessmentA.objects.filter(eval=plan)
    behavior = EvalPreAssessmentB.objects.filter(eval=plan)
    check_ind = EvalPreAssessmentA.objects.filter(eval=plan, scored__isnull=False).exists()
    check_beh = EvalPreAssessmentB.objects.filter(eval=plan, scored__isnull=False).exists()
    context = {
         'title': 'Detail Detail Pre-Assessment', 'legend':'Detail Detail Pre-Assessment', 
         'group': group,  'objects': plan, 'page':'pr-detail', 'individual':individual, 'behavior':behavior,
         'check_ind':check_ind, 'check_beh':check_beh
    }
    return render(request,'perform2/evaluator_preass_detail.html', context)

@login_required
def PerfomEvaluatorLock(request, hashid):
    group = request.user.groups.all()[0].name
    plan = get_object_or_404(EvalPreAssessment,hashed=hashid)
    plan.is_finish = True
    plan.save()
    messages.success(request, 'Susesu Chave')
    return redirect('eval-pre-ass-evaluator-detail', hashid)


# ### INDIVIDUAL 
@login_required
def PerfomEvaluatorIndAdd(request, hashid):
    objects = get_object_or_404(EvalPreAssessmentA,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PreAssIndividuoForm(request.POST, instance=objects)
            if form.is_valid():
                 instance = form.save(commit=False)
                 instance.eval_date = datetime.date.today()
                 instance.usereval = request.user
                 instance.save()
                 log_action(request, model='evaluator_pre_ass_ind_objective', action="Update",field_id=objects.pk)
            messages.success(request, f'Aumenta Sucessu')
            return redirect('eval-pre-ass-evaluator-detail', objects.eval.hashed)
    else: form = PreAssIndividuoForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'ind-add-ps', 'objects':objects,
        'title': 'Aumenta Indikador Individual Objectives', 'legend': 'Aumenta Indikador Individual Objectives'
    }
    return render(request, 'perform2/form.html', context)

@login_required
def PerfomEvaluatorBehAdd(request, hashid):
    objects = get_object_or_404(EvalPreAssessmentB,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PreAssBehaviorForm(request.POST, instance=objects)
            if form.is_valid():
                 instance = form.save(commit=False)
                 instance.eval_date = datetime.date.today()
                 instance.usereval = request.user
                 instance.save()
                 log_action(request, model='evaluator_pre_ass_prof_behavior', action="Update",field_id=objects.pk)
            messages.success(request, f'Aumenta Sucessu')
            return redirect('eval-pre-ass-evaluator-detail', objects.eval.hashed)
    else: form = PreAssBehaviorForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'bhv-add-ps', 'objects':objects,
        'title': 'Aumenta indikador Professional Behavior', 'legend': 'Aumenta indikador Professional Behavior'
    }
    return render(request, 'perform2/form.html', context)



@login_required
def PerfomPreAssEvalAddObjDate(request, hashid):
    objects = get_object_or_404(EvalPreAssessment,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PreAssEvaluatorDateForm(request.POST, instance=objects)

            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            return redirect('eval-pre-ass-evaluator-detail', objects.hashed)
    else: form = PreAssEvaluatorDateForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit',
        'title': 'Aumenta Data', 'legend': 'Aumenta Data'
    }
    return render(request, 'perform2/form.html', context)

@login_required
def PerfomPreAssEvalAddBehDate(request, hashid):
    objects = get_object_or_404(EvalPreAssessment,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PreAssEvaluatorDate2Form(request.POST, instance=objects)

            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            return redirect('eval-pre-ass-evaluator-detail', objects.hashed)
    else: form = PreAssEvaluatorDate2Form(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit',
        'title': 'Aumenta Data', 'legend': 'Aumenta Data'
    }
    return render(request, 'perform2/form.html', context)

@login_required
def PerfomPreAssEvalAddComment(request, hashid):
    objects = get_object_or_404(EvalPreAssessment,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PreAssEvaluatorCommentForm(request.POST, instance=objects)

            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            return redirect('eval-pre-ass-evaluator-detail', objects.hashed)
    else: form = PreAssEvaluatorCommentForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit',
        'title': 'Aumenta Komentario', 'legend': 'Aumenta Komentario'
    }
    return render(request, 'perform2/form.html', context)


import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision, Employee
from contract.models import Category, Contract, EmpPosition
from perform.models import ParameterA, ParameterB, Eval, EvalDetA, EvalDetB
from perform.forms import *
from settings_app.utils import getnewid
from log.utils import log_action

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def PerformDetAImport(request, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(Eval, hashed=hashid)
	objects = ParameterA.objects.filter().all()
	for i in objects:
		newid, new_hashid = getnewid(EvalDetA)
		check = EvalDetA.objects.filter(eval=eval, parameter=i).first()
		if not check:
			obj = EvalDetA(id=newid, eval=eval, parameter=i,\
				user=request.user, hashed=new_hashid)
			obj.save()
			messages.success(request, f'Importa sucessu.')
		else:
			messages.warning(request, f'"{check.parameter}" existe ona.')
	return redirect('c-eval-detail', hashid=hashid)


## NEW HERE
@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformDetAUpdate(request, pk, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(Eval, pk=pk)
	objects = get_object_or_404(EvalDetA, hashed=hashid)
	plan = objects.parameter.eval
	if request.method == 'POST':
		form = EvalDetAForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			log_action(request, model='evaluator_evalution_ind_objective', action="Update",field_id=objects.pk)
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=eval.hashed, hashid2=plan.hashed)
	else: form = EvalDetAForm(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Aumenta Valor Avaliasaun',
		'legend': 'Aumenta Valor Avaliasaun',
		'page': 'eval-a', 'plan':plan, 'objects':objects
	}
	return render(request, 'perform2/form_det.html', context)

@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformDetBUpdate(request, pk, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(Eval, pk=pk)
	objects = get_object_or_404(EvalDetB, hashed=hashid)
	plan = objects.parameter.eval
	if request.method == 'POST':
		form = EvalDetBForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			log_action(request, model='evaluator_evalution_prof_behavior', action="Update",field_id=objects.pk)
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=eval.hashed, hashid2=plan.hashed)
	else: form = EvalDetBForm(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Aumenta Valor Avaliasaun',
		'legend': 'Aumenta Valor Avaliasaun',
		'page': 'eval-b', 'plan':plan, 'objects':objects
	}
	return render(request, 'perform2/form_det.html', context)


# work: NEW HERE
@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformEval4Update(request, hashid, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, pk=pk)
	if request.method == 'POST':
		form = EvalForm4(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=objects.hashed, hashid2=plan.hashed)
	else: form = EvalForm4(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Prienche JUSTIFICATION OF OUTSTANDING PERFORMANCE',
		'legend': 'Prienche JUSTIFICATION OF OUTSTANDING PERFORMANCE',
		'objects':objects, 'page':'form-4', 'plan':plan
	}
	return render(request, 'perform2/form_det.html', context)

@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformEval5Update(request, hashid, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, pk=pk)
	if request.method == 'POST':
		form = EvalForm5(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=objects.hashed, hashid2=plan.hashed)
	else: form = EvalForm5(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Prienche Paramenter of individual objectives',
		'legend': 'Prienche Paramenter of individual objectives',
		'objects':objects, 'page':'form-4', 'plan':plan
	}
	return render(request, 'perform2/form_det.html', context)

@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformEval6Update(request, hashid, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, pk=pk)
	if request.method == 'POST':
		form = EvalForm6(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=objects.hashed, hashid2=plan.hashed)
	else: form = EvalForm6(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Prienche Paramenter professional behaviors',
		'legend': 'Prienche Paramenter professional behaviors',
		'objects':objects, 'page':'form-4', 'plan':plan
	}
	return render(request, 'perform2/form_det.html', context)

@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformEval7Update(request, hashid, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, pk=pk)
	if request.method == 'POST':
		form = EvalForm7(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=objects.hashed, hashid2=plan.hashed)
	else: form = EvalForm7(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Prienche PRECOGNITION OF MERIT (OUTSTANDING PERFORMANCE)',
		'legend': 'Prienche PRECOGNITION OF MERIT (OUTSTANDING PERFORMANCE)',
		'objects':objects, 'page':'form-4', 'plan':plan
	}
	return render(request, 'perform2/form_det.html', context)

@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformEval8Update(request, hashid, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, pk=pk)
	if request.method == 'POST':
		form = EvalForm8(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=objects.hashed, hashid2=plan.hashed)
	else: form = EvalForm8(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Prienche JUSTIFICATION OF NON-EVALUATION',
		'legend': 'Prienche JUSTIFICATION OF NON-EVALUATION',
		'objects':objects, 'page':'form-4', 'plan':plan
	}
	return render(request, 'perform2/form_det.html', context)

@login_required
@allowed_users(allowed_roles=['unit','de', 'deputy'])
def PerformEval9Update(request, hashid, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, pk=pk)
	if request.method == 'POST':
		form = EvalForm9(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			
			messages.success(request, f'Aumenta sucessu.')
			return redirect('eval-evaluator-detail', hashid=objects.hashed, hashid2=plan.hashed)
	else: form = EvalForm9(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Prienche EXPECTATIONS, CONDITIONS AND / OR REQUIREMENTS FOR PERSONAL AND PROFESSIONAL DEVELOPMENT',
		'legend': 'Prienche EXPECTATIONS, CONDITIONS AND / OR REQUIREMENTS FOR PERSONAL AND PROFESSIONAL DEVELOPMENT',
		'objects':objects, 'page':'form-4', 'plan':plan
	}
	return render(request, 'perform2/form_det.html', context)






@login_required
@allowed_users(allowed_roles=['unit','hr'])
def PerformDetBImport(request, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(Eval, hashed=hashid)
	objects = ParameterB.objects.filter().all()
	for i in objects:
		newid, new_hashid = getnewid(EvalDetB)
		check = EvalDetB.objects.filter(eval=eval, parameter=i).first()
		if not check:
			obj = EvalDetB(id=newid, eval=eval, parameter=i,\
				user=request.user, hashed=new_hashid)
			obj.save()
			messages.success(request, f'Importa sucessu.')
		else:
			messages.warning(request, f'"{check.parameter}" existe ona.')
	return redirect('c-eval-detail', hashid=hashid)


### SELF
@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformDetAImport(request, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(EvalSelf, hashed=hashid)
	objects = ParameterA.objects.filter().all()
	for i in objects:
		newid, new_hashid = getnewid(EvalSelfDetA)
		check = EvalSelfDetA.objects.filter(eval=eval, parameter=i).first()
		if not check:
			obj = EvalSelfDetA(id=newid, eval=eval, parameter=i,\
				user=request.user, hashed=new_hashid)
			obj.save()
			messages.success(request, f'Importa sucessu.')
		else:
			messages.warning(request, f'"{check.parameter}" existe ona.')
	return redirect('eval-self-detail', hashid=hashid)



#
@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformDetBImport(request, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(EvalSelf, hashed=hashid)
	objects = ParameterB.objects.filter().all()
	for i in objects:
		newid, new_hashid = getnewid(EvalSelfDetB)
		check = EvalSelfDetB.objects.filter(eval=eval, parameter=i).first()
		if not check:
			obj = EvalSelfDetB(id=newid, eval=eval, parameter=i,\
				user=request.user, hashed=new_hashid)
			obj.save()
			messages.success(request, f'Importa sucessu.')
		else:
			messages.warning(request, f'"{check.parameter}" existe ona.')
	return redirect('eval-self-detail', hashid=hashid)

@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformDetBUpdateBack(request, pk, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(EvalSelf, pk=pk)
	objects = get_object_or_404(EvalSelfDetB, hashed=hashid)
	if request.method == 'POST':
		form = EvalSelfDetBForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			messages.success(request, f'Altera sucessu.')
			return redirect('eval-self-detail', hashid=eval.hashed)
	else: form = EvalSelfDetBForm(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Altera Avaliasaun ba Paramenter B',
		'legend': 'Altera Avaliasaun ba Paramenter B'
	}
	return render(request, 'perform2/form_det.html', context)




# Generated by Django 3.2 on 2022-12-11 11:44

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('custom', '0012_alter_department_leader'),
        ('employee', '0018_employee_pin'),
        ('contract', '0014_alter_contract_file'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Eval',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('score_a', models.IntegerField(blank=True, null=True)),
                ('score_b', models.IntegerField(blank=True, null=True)),
                ('total', models.IntegerField(blank=True, null=True)),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='custom.position')),
            ],
        ),
        migrations.CreateModel(
            name='EvalChoice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
                ('score', models.IntegerField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='EvalSelf',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('comments', models.TextField(blank=True, null=True)),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='custom.position')),
            ],
        ),
        migrations.CreateModel(
            name='EvalType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='EvalYear',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('year', models.IntegerField(blank=True, null=True)),
                ('is_active', models.BooleanField(default=False, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ParameterA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
                ('measure', models.TextField(blank=True, null=True)),
                ('criteria', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ParameterB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('area', models.CharField(blank=True, max_length=100, null=True)),
                ('indicator', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Evaluator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='employee.employee')),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='perform.eval')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='custom.position')),
                ('unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='custom.unit')),
            ],
        ),
        migrations.CreateModel(
            name='EvalSelfDetB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments_a', models.TextField(blank=True, null=True)),
                ('comments_b', models.TextField(blank=True, null=True)),
                ('comments_c', models.TextField(blank=True, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdetb', to='perform.evalself')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdetb', to='perform.parameterb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalSelfDetA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments_a', models.TextField(blank=True, null=True, verbose_name='Goal Exceeded')),
                ('comments_b', models.TextField(blank=True, null=True, verbose_name='Goal Achieved')),
                ('comments_c', models.TextField(blank=True, null=True, verbose_name='Goal Not Reached')),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdeta', to='perform.evalself')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdeta', to='perform.parametera')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='evalself',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='perform.evaltype'),
        ),
        migrations.AddField(
            model_name='evalself',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='custom.unit'),
        ),
        migrations.AddField(
            model_name='evalself',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='evalself',
            name='year',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='perform.evalyear'),
        ),
        migrations.CreateModel(
            name='EvalFinalScore',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('a', models.IntegerField(blank=True, null=True)),
                ('b', models.IntegerField(blank=True, null=True)),
                ('c', models.IntegerField(blank=True, null=True)),
                ('d', models.IntegerField(blank=True, null=True)),
                ('e', models.IntegerField(blank=True, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalfinalscore', to='perform.eval')),
            ],
        ),
        migrations.CreateModel(
            name='EvalDetB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments', models.TextField(blank=True, null=True, verbose_name='Komentariu')),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('choice', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.evalchoice')),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.eval')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.parameterb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalDetA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments', models.TextField(blank=True, null=True, verbose_name='Komentariu')),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('choice', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.evalchoice')),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.eval')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.parametera')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalDate',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_a_1', models.DateField(blank=True, null=True)),
                ('date_a_2', models.DateField(blank=True, null=True)),
                ('date_b_1', models.DateField(blank=True, null=True)),
                ('date_b_2', models.DateField(blank=True, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldate', to='perform.eval')),
            ],
        ),
        migrations.AddField(
            model_name='eval',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='perform.evaltype'),
        ),
        migrations.AddField(
            model_name='eval',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='custom.unit'),
        ),
        migrations.AddField(
            model_name='eval',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='eval',
            name='year',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='perform.evalyear'),
        ),
    ]



# Generated by Django 3.2 on 2023-03-07 01:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0019_auto_20230307_0950'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='evalplanning',
            name='comment_next_evaluation',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='just_non_evaluation',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='outstanding_perf',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='recognition_merit',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='unsatisfactory_perf_beh',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='unsatisfactory_perf_obj',
        ),
    ]



from django.db.models.signals import post_save
from django.dispatch import receiver
from django.contrib.auth.models import User
from .models import Eval, Evaluator, EvalDate, EvalFinalScore

@receiver(post_save, sender=Eval)
def create_eval(sender, instance, created, **kwargs):
	
	if created:
		Evaluator.objects.create(id=instance.id, eval=instance)
		EvalDate.objects.create(id=instance.id, eval=instance)
		EvalFinalScore.objects.create(id=instance.id, eval=instance)


from .c_perform_v import *
from .c_perform_m import *
from .all_perform_v import *
from .perform_m import *
from .perform_conf import *
from .self_perform_v import *
from .self_perform_m import *
from .perform_r import *
from .perform_conf_m import *
from .perfom_plan import *
from .perform_staff import *
from .perform_pre_ass import *


from django.contrib import admin
from .models import *

admin.site.register(EvalYear)
admin.site.register(EvalType)
admin.site.register(EvalChoice)
admin.site.register(ParameterA)
admin.site.register(ParameterB)
admin.site.register(Eval)
admin.site.register(Evaluator)
admin.site.register(EvalFinalScore)
admin.site.register(EvalDate)
admin.site.register(EvalDetA)
admin.site.register(EvalDetB)
admin.site.register(EvalSelf)
admin.site.register(EvalSelfDetA)
admin.site.register(EvalSelfDetB)
admin.site.register(EvalChoicePlanning)
admin.site.register(EvalPlanning)
admin.site.register(EvalPlanningA)
admin.site.register(EvalPlanningB)
admin.site.register(EvalPreAssessment)
admin.site.register(EvalPreAssessmentA)
admin.site.register(EvalPreAssessmentB)


import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision, Employee
from contract.models import Category, Contract, EmpPosition
from perform.models import ParameterA, ParameterB, Eval, EvalDetA, EvalDetB, EvalYear, \
EvalPlanning, EvalPlanningB, EvalType
from perform.forms import *
from settings_app.utils import getnewid
from settings_app.user_utils import c_staff, c_unit
from log.utils import log_action

@login_required
@allowed_users(allowed_roles=['admin','hr', 'staff', 'dep', 'unit', 'deputy'])
def PerfomPlanAddObjective(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningObjectiveForm(request.POST, instance=objects)
            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            if group == 'hr':
                return redirect('eval-conf-plan-detail', hashid)
            else:
                return redirect('staff-perform-plan-detail', hashid)
    else: form = PlanningObjectiveForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit', 
        'objects': objects,
        'title': 'Aumenta Objectives', 'legend': 'Aumenta Objectives'
    }
    return render(request, 'perform2/form.html', context)


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerfomPlanDetail(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    user = c_staff(request.user)
    check_emp = True if user == objects.employee else False
    individual = EvalPlanningA.objects.filter(eval=objects)
    behavior = EvalPlanningB.objects.filter(eval=objects)
    context = {
        'title': 'Detail Planning and Monitoring', 'legend': 'Planning and Monitoring Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior
    }
    return render(request,'perform2/plan_detail.html', context)


@login_required
@allowed_users(allowed_roles=['admin','hr', 'staff', 'dep', 'unit', 'deputy' ])
def PerfomPlanAddA(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            newid, new_hashid = getnewid(EvalPlanningA)
            form = PlanningAForm(request.POST)

            if form.is_valid():
                 instance = form.save(commit=False)
                 instance.id = newid
                 instance.hashed = new_hashid
                 instance.eval = objects
                 instance.enter_date = datetime.date.today()
                 instance.user = request.user
                 instance.save()
            messages.success(request, f'Aumeta Sucessu')
            if group == 'hr':
                return redirect('eval-conf-plan-detail', hashid)
            else:
                return redirect('staff-perform-plan-detail', hashid)
    else: form = PlanningAForm()
    context = {
        'group': group, 'form': form, 'page': 'unit','objects': objects,
        'title': 'Aumenta Individual Activities', 'legend': 'Aumenta Individual Activities'
    }
    return render(request, 'perform2/form.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr', 'staff', 'dep', 'unit', 'deputy' ])
def PerfomPlanUdpateA(request, hashid):
    objects = get_object_or_404(EvalPlanningA,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningAForm(request.POST, instance=objects)

            if form.is_valid():
                 instance = form.save(commit=False)
                 instance.eval_date = datetime.date.today()
                 instance.user = request.user
                 instance.save()
                 log_action(request, model='individual_activity', action="Update",field_id=objects.pk)
            messages.success(request, f'Altera Sucessu')
            if group == 'hr':
                return redirect('eval-conf-plan-detail', hashid)
            else:
                return redirect('staff-perform-plan-detail', hashid=objects.eval.hashed)
    else: form = PlanningAForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit', 'objects': objects.eval,
        'title': 'Altera Individual Activities', 'legend': 'Altera Individual Activities'
    }
    return render(request, 'perform2/form.html', context)

@login_required
def PerfomPlanDeleteA(request, hashid, hashid2):
    group = request.user.groups.all()[0].name
    objects = get_object_or_404(EvalPlanningA,hashed=hashid)
    plan = get_object_or_404(EvalPlanning,hashed=hashid2)
    log_action(request, model='individual_activity', action="Delete",field_id=objects.pk)
    objects.delete()
    messages.success(request, f'Delete Sucessu')
    if group == 'hr':
        return redirect('eval-conf-plan-detail', hashid)
    else:
        return redirect('staff-perform-plan-detail', hashid=objects.eval.hashed)


@login_required
def PerfomPlanDeleteB(request, hashid, hashid2):
    group = request.user.groups.all()[0].name
    objects = get_object_or_404(EvalPlanningB,hashed=hashid)
    plan = get_object_or_404(EvalPlanning,hashed=hashid2)
    objects.delete()
    messages.success(request, f'Delete Sucessu')
    if group == 'hr':
        return redirect('eval-conf-plan-detail', plan.hashed)
    else:
        return redirect('staff-perform-plan-detail',plan.hashed)



@login_required
def PerfomPlanLock(request, hashid):
    group = request.user.groups.all()[0].name
    plan = get_object_or_404(EvalPlanning,hashed=hashid)
    if plan.ind_date != None and plan.obj_date != None:
        plan.is_lock = True
        plan.save()
        messages.success(request, f'Chave Sucessu')
        if group == 'hr':
            return redirect('eval-conf-plan-detail', plan.hashed)
        else:
            return redirect('staff-perform-plan-detail',plan.hashed)
    else:
        messages.error(request, f'Data Seidauk Prienche')
        if group == 'hr':
            return redirect('eval-conf-plan-detail', plan.hashed)
        else:
            return redirect('staff-perform-plan-detail',plan.hashed)
         




# EVALUATOR PLAN
@login_required
@allowed_users(allowed_roles=['de', 'unit'])
def PerfomPlanEvaluatorAdd(request, hashid):
    emp, unit = c_unit(request.user)
    plan = get_object_or_404(EvalPlanning,hashed=hashid)
    contract = Contract.objects.filter(employee=emp, is_active=True).last()
    empdiv = CurEmpDivision.objects.filter(employee=emp).last()
    plan.employeeeval = emp
    plan.positioneval = contract.position
    plan.uniteval = empdiv.unit
    plan.save()
    messages.success(request, f'Chave Sucessu')
    return redirect('eval-conf-plan-evaluator-detail', plan.hashed)

@login_required
@allowed_users(allowed_roles=['de', 'unit'])
def PerfomPlanEvaluatorDetail(request, hashid):
    group = request.user.groups.all()[0].name
    plan = get_object_or_404(EvalPlanning,hashed=hashid)
    individual = EvalPlanningA.objects.filter(eval=plan)
    behavior = EvalPlanningB.objects.filter(eval=plan)
    check_ind = EvalPlanningA.objects.filter(eval=plan).exists()
    check_beh = EvalPlanningB.objects.filter(eval=plan).exists()
    context = {
         'title': 'Detail Planning and Monitoring', 'legend':'Detail Planning and Monitoring', 
         'group': group,  'objects': plan, 'page':'pr-detail', 'individual':individual, 'behavior':behavior,
         'check_ind':check_ind, 'check_beh':check_beh
    }
    return render(request,'perform2/evaluator_plan_detail.html', context)

@login_required
@allowed_users(allowed_roles=['de', 'unit'])
def PerfomPlanEvaluatorLock(request, hashid):
    group = request.user.groups.all()[0].name
    plan = get_object_or_404(EvalPlanning,hashed=hashid)
    if plan.eval_date_obj != None and plan.eval_date_ind != None:
        plan.is_finish = True
        plan.save()
        messages.success(request, 'Susesu Chave')
        return redirect('eval-conf-plan-evaluator-detail', hashid)
    else:
        messages.error(request, 'Data seidauk prienche')
        return redirect('eval-conf-plan-evaluator-detail', hashid)
         


### INDIVIDUAL 
@login_required
def PerfomPlanIndividualAdd(request, hashid):
    objects = get_object_or_404(EvalPlanningA,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningIndividualForm(request.POST, instance=objects)
            if form.is_valid():
                 instance = form.save(commit=False)
                 instance.eval_date = datetime.date.today()
                 instance.usereval = request.user
                 instance.save()
                 log_action(request, model='evaluator_individual_activity', action="Update",field_id=objects.pk)
            messages.success(request, f'Aumenta Sucessu')
            return redirect('eval-conf-plan-evaluator-detail', objects.eval.hashed)
    else: form = PlanningIndividualForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'ind-add', 'objects':objects,
        'title': 'Aumenta Individual  Objectives', 'legend': 'Aumenta Individual  Objectives'
    }
    return render(request, 'perform2/form.html', context)

@login_required
def PerfomPlanBehaviorAdd(request, hashid):
    objects = get_object_or_404(EvalPlanningB,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningBehaviorForm(request.POST, instance=objects)
            if form.is_valid():
                 instance = form.save(commit=False)
                 instance.eval_date = datetime.date.today()
                 instance.usereval = request.user
                 instance.save()
                 log_action(request, model='evaluator_prof_behavior', action="Update",field_id=objects.pk)
            messages.success(request, f'Aumenta Sucessu')
            return redirect('eval-conf-plan-evaluator-detail', objects.eval.hashed)
    else: form = PlanningBehaviorForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'beh-add', 'objects':objects,
        'title': 'Aumenta Professional Behavior', 'legend': 'Aumenta Professional Behavior'
    }
    return render(request, 'perform2/form.html', context)


@login_required
def PerfomPlanAddObjDate(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningDate2Form(request.POST, instance=objects)

            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            if group == 'hr':
                return redirect('eval-conf-plan-detail', hashid)
            else:
                return redirect('staff-perform-plan-detail',hashid)
    else: form = PlanningDate2Form(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit', 'objects':objects,
        'title': 'Aumenta Data', 'legend': 'Aumenta Data'
    }
    return render(request, 'perform2/form.html', context)
@login_required
def PerfomPlanAddBehDate(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningDateForm(request.POST, instance=objects)

            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            if group == 'hr':
                return redirect('eval-conf-plan-detail', hashid)
            else:
                return redirect('staff-perform-plan-detail',hashid)
    else: form = PlanningDateForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit', 'objects':objects,
        'title': 'Aumenta Data', 'legend': 'Aumenta Data'
    }
    return render(request, 'perform2/form.html', context)


@login_required
def PerfomPlanEvalAddObjDate(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningEvaluatorDate2Form(request.POST, instance=objects)

            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            return redirect('eval-conf-plan-evaluator-detail', objects.hashed)
    else: form = PlanningEvaluatorDate2Form(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit',
        'title': 'Aumenta Data', 'legend': 'Aumenta Data'
    }
    return render(request, 'perform2/form.html', context)
@login_required
def PerfomPlanEvalAddBehDate(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    group = request.user.groups.all()[0].name
    if request.method == 'POST':
            form = PlanningEvaluatorDateForm(request.POST, instance=objects)

            if form.is_valid():
                 form.save()
            messages.success(request, f'Aumeta Sucessu')
            return redirect('eval-conf-plan-evaluator-detail', objects.hashed)
    else: form = PlanningEvaluatorDateForm(instance=objects)
    context = {
        'group': group, 'form': form, 'page': 'unit',
        'title': 'Aumenta Data', 'legend': 'Aumenta Data'
    }
    return render(request, 'perform2/form.html', context)


from django.urls import path
from . import views

urlpatterns = [
	###
	path('c/dash/', views.cPerformDash, name="c-eval-dash"),
	path('c/list/', views.cPerformList, name="c-eval-list"),
	path('c/year/list/<str:year>/', views.cPerformYearList, name="c-eval-year-list"),
	path('c/cat/list/<str:pk>/', views.cPerformCatList, name="c-eval-cat-list"),
    
	##NEW
	path('conf/add-eval/<str:hashid>/<int:year>/', views.PerfomConfAddEval, name="eval-add-eval"),
	path('conf/detail-eval/<str:hashid>/<str:hashid2>/', views.PerfomEvalDetail, name="eval-detail-eval"),
	## EVAL EVALUATOR
    path('evaluator/add/<str:hashid>/<str:hashid2>/', views.PerfomEvalEvaluatorAdd, name="eval-evaluator-add"),
    path('evaluator/detail/<str:hashid>/<str:hashid2>/', views.PerfomEvalEvaluatorDetail, name="eval-evaluator-detail"),
	path('evaluator/updateA/<str:pk>/<str:hashid>/', views.PerformDetAUpdate, name="c-eval-update_a"),
	path('evaluator/updateB/<str:pk>/<str:hashid>/', views.PerformDetBUpdate, name="c-eval-update_b"),
	path('evaluator/lock/<str:hashid>/<str:hashid2>/', views.cPerformLock, name="c-eval-lock"),
	path('evaluator/refresh/<str:hashid>/<str:hashid2>/', views.cPerformRefresh, name="c-eval-refresh"),
	path('evaluator/update/outstanding/<str:hashid>/<int:pk>/', views.PerformEval4Update, name="c-eval-update-outstanding"),
	path('evaluator/update/unsatisfactory/A/<str:hashid>/<int:pk>/', views.PerformEval5Update, name="c-eval-update-uns-A"),
	path('evaluator/update/unsatisfactory/B/<str:hashid>/<int:pk>/', views.PerformEval6Update, name="c-eval-update-uns-B"),
	path('evaluator/update/merit/<str:hashid>/<int:pk>/', views.PerformEval7Update, name="c-eval-update-merit"),
	path('evaluator/update/jus-non-evaluation/<str:hashid>/<int:pk>/', views.PerformEval8Update, name="c-eval-update-jus-non-eval"),
	path('evaluator/update/expectation/<str:hashid>/<int:pk>/', views.PerformEval9Update, name="c-eval-update-exp"),
    

	path('c/add/', views.cPerformAdd, name="c-eval-add"),
	path('c/update/<str:hashid>/', views.cPerformUpdate, name="c-eval-update"),
	path('c/detail/<str:hashid>/', views.cPerformDetail, name="c-eval-detail"),
	path('c/remove/<str:hashid>/', views.cPerformRemove, name="c-eval-remove"),
	path('c/unlock/<str:hashid>/', views.cPerformUnlock, name="c-eval-unlock"),
	path('c/finish/<str:hashid>/', views.cPerformFinish, name="c-eval-finish"),
	path('c/date/update1/<str:pk>/', views.cPerformDate1Update, name="c-evaldate-update1"),
	path('c/date/update2/<str:pk>/', views.cPerformDate2Update, name="c-evaldate-update2"),
	#
	path('c/det/importA/<str:hashid>/', views.PerformDetAImport, name="c-eval-import_a"),
	path('c/det/importB/<str:hashid>/', views.PerformDetBImport, name="c-eval-import_b"),
	### ALL
	path('all/dash/', views.allPerformDash, name="all-eval-dash"),
	path('all/list/', views.allPerformList, name="all-eval-list"),
	path('all/detail/<str:hashid>/', views.allPerformDetail, name="all-eval-detail"),
	path('all/year/list/<str:year>/', views.allPerformYearList, name="all-eval-year-list"),
	path('all/cat/list/<str:pk>/', views.allPerformCatList, name="all-eval-cat-list"),
	path('all/cat/eval/list/<str:pk>/', views.allPerformCatEvalList, name="all-eval-cat-eval-list"),
	path('all/cat/not/list/<str:pk>/', views.allPerformCatNotList, name="all-eval-cat-not-list"),
	### CONF
	path('conf/dash/', views.PerformConfDash, name="eval-conf-dash"),
	path('conf/behavior/list/', views.PerformConfBehaviorList, name="eval-conf-behavior-list"),
	path('conf/year/active/<str:pk>/', views.PerformYearActive, name="eval-conf-year-active"),
	path('conf/eval/parama/add/', views.ParameterAAdd, name="eval-parama-add"),
	path('conf/eval/parama/update/<str:pk>/', views.ParameterAUpdate, name="eval-parama-update"),
	path('conf/eval/paramb/add/', views.ParameterBAdd, name="eval-paramb-add"),
	path('conf/eval/paramb/update/<str:pk>/', views.ParameterBUpdate, name="eval-paramb-update"),
	### PLAN
	path('conf/add/plan/<str:hashid>/<int:year>/', views.PerfomConfAddPlan, name="eval-conf-add-plan"),
	path('conf/add/plan-all/<int:year>/', views.PerfomConfAddPlanAll, name="eval-conf-add-plan-all"),
	path('conf/plan-detail/<str:hashid>/', views.PerfomPlanDetail, name="eval-conf-plan-detail"),
	path('conf/plan-add/A/<str:hashid>/', views.PerfomPlanAddA, name="eval-conf-plan-add-a"),
	path('conf/plan-update/A/<str:hashid>/', views.PerfomPlanUdpateA, name="eval-conf-plan-update-a"),
	path('conf/plan-delete/A/<str:hashid>/<str:hashid2>/', views.PerfomPlanDeleteA, name="eval-conf-plan-delete-a"),
	path('conf/behavior-add/B/<str:hashid>/', views.PerformConfBehaviorAdd, name="eval-conf-plan-add-b"),
	path('conf/behavior-delete/B/<str:hashid>/<str:hashid2>/', views.PerfomPlanDeleteB, name="eval-conf-behavior-delete-b"),
	path('conf/plan-add/objective/<str:hashid>/', views.PerfomPlanAddObjective, name="eval-conf-plan-add-objectives"),
	path('conf/plan-lock/<str:hashid>/', views.PerfomPlanLock, name="eval-conf-plan-lock"),
	path('conf/plan-add/beh-date/<str:hashid>/', views.PerfomPlanAddBehDate, name="eval-conf-plan-add-beh-date"),
	path('conf/plan-add/obj-date/<str:hashid>/', views.PerfomPlanAddObjDate, name="eval-conf-plan-add-obj-date"),


	## PLAN EVALUATOR
	path('plan-evaluator/add/<str:hashid>/', views.PerfomPlanEvaluatorAdd, name="eval-conf-plan-evaluator-add"),
	path('plan-evaluator/detail/<str:hashid>/', views.PerfomPlanEvaluatorDetail, name="eval-conf-plan-evaluator-detail"),
	path('plan-evaluator/individual/add/<str:hashid>/', views.PerfomPlanIndividualAdd, name="eval-conf-plan-evaluator-ind-add"),
	path('plan-evaluator/behavior/add/<str:hashid>/', views.PerfomPlanBehaviorAdd, name="eval-conf-plan-evaluator-beh-add"),
	path('plan-evaluator/lock/<str:hashid>/', views.PerfomPlanEvaluatorLock, name="eval-conf-plan-evaluator-lock"),
	path('plan-eval-add/beh-date/<str:hashid>/', views.PerfomPlanEvalAddBehDate, name="eval-conf-plan-eval-add-beh-date"),
	path('plan-eval-add/obj-date/<str:hashid>/', views.PerfomPlanEvalAddObjDate, name="eval-conf-plan-eval-add-obj-date"),
	 
	###PRE ASSESSMENT ###
	path('conf/add/pre-ass/<str:hashid>/<int:year>/', views.PerfomConfAddPreAss, name="eval-conf-add-pre-ass"),
	path('conf/pre-ass/detail/<str:hashid>/', views.PerfomConfPreAssDetail, name="eval-conf-pre-ass-detail"),
	path('conf/pre-ass-lock/<str:hashid>/', views.PerfomPreAssLock, name="eval-pre-ass-lock"),
	path('conf/add/A/pre-ass/<str:hashid>/', views.PerfomConfPreAssAddA, name="eval-conf-pre-ass-add-a"),
	path('conf/add/B/pre-ass/<str:hashid>/', views.PerfomConfPreAssAddB, name="eval-conf-pre-ass-add-b"),
	path('preass-evaluator/add/<str:hashid>/', views.PerfomEvaluatorAdd, name="eval-pre-ass-evaluator-add"),
	path('preass-evaluator/detail/<str:hashid>/', views.PerfomEvaluatorDetail, name="eval-pre-ass-evaluator-detail"),
	path('preass-evaluator/add-ind/<str:hashid>/', views.PerfomEvaluatorIndAdd, name="eval-pre-ass-evaluator-add-ind"),
	path('preass-evaluator/add-beh/<str:hashid>/', views.PerfomEvaluatorBehAdd, name="eval-pre-ass-evaluator-add-beh"),
	path('preass-evaluator/lock/<str:hashid>/', views.PerfomEvaluatorLock, name="eval-pre-ass-evaluator-lock"),
	path('preass-evaluator/add-date1/<str:hashid>/', views.PerfomPreAssEvalAddObjDate, name="eval-pre-ass-evaluator-add-date-obj"),
	path('preass-evaluator/add-date2/<str:hashid>/', views.PerfomPreAssEvalAddBehDate, name="eval-pre-ass-evaluator-add-date-beh"),
	path('preass-evaluator/add-comment/<str:hashid>/', views.PerfomPreAssEvalAddComment, name="eval-pre-ass-evaluator-add-comment"),
	

	### SELF
	path('self/add/<str:hashid>/<int:year>/', views.PerfomConfAddSelfEval, name="hr-eval-self-add"),
	path('self/conf-detail/<str:hashid>/', views.PerfomConfSelfDetail, name="hr-eval-self-detail"),
	path('self/add-ind/<str:hashid>/', views.selfPerformDetAUpdate, name="eval-self-add-ind"),
	path('self/add-bhv/<str:hashid>/', views.selfPerformDetBUpdate, name="eval-self-add-bhv"),
	path('self/lock/<str:hashid>/', views.selfPerformLock, name="eval-self-lock"),
	path('self/add-date1/<str:hashid>/', views.SelfEvalAddObjDate, name="eval-self-add-date-obj"),
	path('self/add-date2/<str:hashid>/', views.SelfEvalAddBehDate, name="eval-self-add-date-beh"),
	path('self/add-comment/<str:hashid>/', views.SelfEvalAddComment, name="eval-self-add-comment"),
    
	##EVALUATOR SELF
	path('evaluator-self/detail/<str:hashid>/', views.PerfomEvaluatorSelfDetail, name="evaluator-eval-self-detail"),

    path('self/list/', views.selfPerformList, name="eval-self-list"),
	path('self/add/<str:page>/', views.selfPerformAdd, name="eval-self-add"),
	path('self/detail/<str:hashid>/', views.selfPerformDetail, name="eval-self-detail"),
	path('self/update/<str:hashid>/', views.selfPerformUpdate, name="eval-self-update"),
	path('self/com/update/<str:hashid>/', views.selfPerformComUpdate, name="eval-self-com-update"),
	path('self/remove/<str:hashid>/', views.selfPerformRemove, name="eval-self-remove"),
	path('self/unlock/<str:hashid>/', views.selfPerformUnlock, name="eval-self-unlock"),
	path('self/finish/<str:hashid>/', views.selfPerformFinish, name="eval-self-finish"),

	path('emp/s/det/importA/<str:hashid>/', views.selfPerformDetAImport, name="eval-self-import_a"),
	path('emp/s/det/updateA/<str:pk>/<str:hashid>/', views.selfPerformDetAUpdate, name="eval-self-update_a"),
	path('emp/s/det/importB/<str:hashid>/', views.selfPerformDetBImport, name="eval-self-import_b"),
	# path('emp/s/det/updateB/<str:pk>/<str:hashid>/', views.selfPerformDetBUpdate, name="eval-self-update_b"),
	#
	path('self/all/list/', views.selfPerformAllList, name="eval-self-all-list"),
	path('self/year/list/<str:year>/', views.selfPerformYearList, name="eval-self-year-list"),
	path('self/unit/list/', views.selfPerformUnitList, name="eval-self-unit-list"),
	path('self/unit/year/list/<str:year>/', views.selfPerformUnitYearList, name="eval-self-unit-year-list"),
	path('self/all/detail/<str:hashid>/', views.selfPerformAllDetail, name="eval-self-all-detail"),
    
	### STAFF
	path('staff/list/', views.StaffListPerfom, name="staff-perform-list"),
    
	### STAFF PLAN
	path('staff/plan-detail/<str:hashid>/', views.StaffPerfomPlanDetail, name="staff-perform-plan-detail"),
    
	### STAFF PRE ASS
	path('staff/preass-detail/<str:hashid>/', views.StaffPerfomPreAssDetail, name="staff-perform-preass-detail"),
	### SELF
	path('staff/self-detail/<str:hashid>/', views.StaffPerformSelfDetail, name="staff-perform-self-detail"),
    ### EVAL
    path('staff/eval-detail/<str:hashid>/<str:hashid2>/', views.StaffEvalDetail, name="staff-eval-detail"),
]


# Generated by Django 3.2 on 2023-02-16 13:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0003_evalplanninga_evalplanningb'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanninga',
            name='eval_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2 on 2023-03-10 00:23

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0021_auto_20230307_1027'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvalMonth',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('year', models.CharField(blank=True, max_length=100, null=True)),
            ],
        ),
        migrations.AddField(
            model_name='evaltype',
            name='month',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='perform.evalmonth'),
        ),
    ]



from django import forms
from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Submit, Row, Column, Button, HTML
from django.db.models import Q
from django.contrib.auth.models import User
from employee.models import Employee
from perform.models import ParameterA, ParameterB, Eval, EvalDetA, EvalDetB, EvalDate,\
	EvalSelf, EvalSelfDetA, EvalSelfDetB, EvalPlanningA, EvalPlanningB, EvalPreAssessmentA, EvalPreAssessmentB, EvalPlanning, EvalPreAssessment
from django_summernote.widgets import SummernoteWidget

class DateInput(forms.DateInput):
	input_type = 'date'

class ParameterAForm(forms.ModelForm):
	measure = forms.CharField(label="Measuring", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	criteria = forms.CharField(label="Criteria", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = ParameterA
		fields = ['name','measure','criteria']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		
		self.helper.layout = Layout(
			Row(
				Column('name', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('measure', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('criteria', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class ParameterBForm(forms.ModelForm):
	indicator = forms.CharField(label="Indicator", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = ParameterB
		fields = ['area','indicator']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('area', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('indicator', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)
### EVAL ###
class EvalForm(forms.ModelForm):
	start_date = forms.DateField(label='Data Hahu', widget=DateInput(), required=False)
	end_date = forms.DateField(label='Data Remata', widget=DateInput(), required=False)
	class Meta:
		model = Eval
		fields = ['employee','start_date','end_date']
	def __init__(self, emp, unit, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.fields['employee'].queryset = Employee.objects.filter((Q(curempdivision__department__unit=unit)|\
			Q(curempdivision__unit=unit)))\
			.exclude((Q(id=emp.id)|Q(curempdivision__department__id=3)|Q(contract__category_id=6))).all()
		self.helper = FormHelper()
		self.fields['employee'].required = True
		self.fields['start_date'].required = True
		self.fields['end_date'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('employee', css_class='form-group col-md-6 mb-0'),
				Column('start_date', css_class='form-group col-md-3 mb-0'),
				Column('end_date', css_class='form-group col-md-3 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalForm2(forms.ModelForm):
	start_date = forms.DateField(label='Data Hahu', widget=DateInput(), required=False)
	end_date = forms.DateField(label='Data Ikus', widget=DateInput(), required=False)
	class Meta:
		model = Eval
		fields = ['start_date','end_date']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('start_date', css_class='form-group col-md-3 mb-0'),
				Column('end_date', css_class='form-group col-md-3 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalDateForm1(forms.ModelForm):
	date_a_1 = forms.DateField(label='Data Evaluator', widget=DateInput(), required=False)
	date_a_2 = forms.DateField(label='Data Evaluated', widget=DateInput(), required=False)
	class Meta:
		model = EvalDate
		fields = ['date_a_1','date_a_2']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('date_a_1', css_class='form-group col-md-3 mb-0'),
				Column('date_a_2', css_class='form-group col-md-3 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalDateForm2(forms.ModelForm):
	date_b_1 = forms.DateField(label='Data Evaluator', widget=DateInput(), required=False)
	date_b_2 = forms.DateField(label='Data Evaluated', widget=DateInput(), required=False)
	class Meta:
		model = EvalDate
		fields = ['date_b_1','date_b_2']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('date_b_1', css_class='form-group col-md-3 mb-0'),
				Column('date_b_2', css_class='form-group col-md-3 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalForm4(forms.ModelForm):
	outstanding_perf = forms.CharField(label="Justification Of Outstanding Performance", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalDate
		fields = ['outstanding_perf']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['outstanding_perf'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('outstanding_perf', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalForm5(forms.ModelForm):
	unsatisfactory_perf_obj = forms.CharField(label="Parameter of Individual Objectives", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalDate
		fields = ['unsatisfactory_perf_obj']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['unsatisfactory_perf_obj'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('unsatisfactory_perf_obj', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)


class EvalForm6(forms.ModelForm):
	unsatisfactory_perf_beh = forms.CharField(label="Parameter of Individual Behaviors", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalDate
		fields = ['unsatisfactory_perf_beh']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['unsatisfactory_perf_beh'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('unsatisfactory_perf_beh', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalForm7(forms.ModelForm):
	recognition_merit = forms.CharField(label="Recognition Of Merit (Outstanding Performance)", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalDate
		fields = ['recognition_merit']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['recognition_merit'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('recognition_merit', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)
class EvalForm8(forms.ModelForm):
	just_non_evaluation = forms.CharField(label="Justification Of Non-Evaluation", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalDate
		fields = ['just_non_evaluation']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['just_non_evaluation'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('just_non_evaluation', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalForm9(forms.ModelForm):
	comment_next_evaluation = forms.CharField(label="Evaluation, Conditions And / Or Requirements for Personal and professional Development", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalDate
		fields = ['comment_next_evaluation']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['comment_next_evaluation'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('comment_next_evaluation', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)
###
class EvalDetAForm(forms.ModelForm):
	class Meta:
		model = EvalDetA
		fields = ['choice','comments']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['choice'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('choice', css_class='form-group col-md-3 mb-0'),
				Column('comments', css_class='form-group col-md-9 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalDetBForm(forms.ModelForm):
	class Meta:
		model = EvalDetB
		fields = ['choice','comments']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['choice'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('choice', css_class='form-group col-md-3 mb-0'),
				Column('comments', css_class='form-group col-md-9 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)
###
class EvalSelfForm(forms.ModelForm):
	start_date = forms.DateField(label='Data Hahu', widget=DateInput(), required=False)
	end_date = forms.DateField(label='Data Remata', widget=DateInput(), required=False)
	eval_date = forms.DateField(label='Data Avaliasaun', widget=DateInput(), required=False)
	class Meta:
		model = EvalSelf
		fields = ['start_date','end_date','eval_date','comments']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('start_date', css_class='form-group col-md-4 mb-0'),
				Column('end_date', css_class='form-group col-md-4 mb-0'),
				Column('eval_date', css_class='form-group col-md-4 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalSelfForm2(forms.ModelForm):
	comments = forms.CharField(label="Komentariu", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalSelf
		fields = ['comments']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('comments', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalSelfDetAForm(forms.ModelForm):
	comments_a = forms.CharField(label="Goal Exceeded", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	comments_b = forms.CharField(label="Goal Achieved", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	comments_c = forms.CharField(label="Goal Not Reached", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalSelfDetA
		fields = ['comments_a','comments_b','comments_c']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('comments_a', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('comments_b', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('comments_c', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class EvalSelfDetBForm(forms.ModelForm):
	comments_a = forms.CharField(label="Demonstrated Competence at a High Level (Explain)", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	comments_b = forms.CharField(label="Demonstrated Competence (Explain)", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	comments_c = forms.CharField(label="Competence not Demonstrated or not existent (Explain)", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalSelfDetB
		fields = ['comments_a','comments_b','comments_c']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('comments_a', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('comments_b', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('comments_c', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class SelfDateForm(forms.ModelForm):
	ind_date = forms.DateField(label='Individual Objective Date', widget=DateInput())
	class Meta:
		model = EvalSelf
		fields = ['ind_date']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['ind_date'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('ind_date', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class SelfDate2Form(forms.ModelForm):
	beh_date = forms.DateField(label='Professional Behavior Date', widget=DateInput())
	class Meta:
		model = EvalSelf
		fields = ['beh_date']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['beh_date'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('beh_date', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class SelfCommentForm(forms.ModelForm):
	comments = forms.CharField(label="Comments", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalSelf
		fields = ['comments']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['comments'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('comments', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

# PLANNING
class PlanningAForm(forms.ModelForm):
	goals = forms.CharField(label="Goal/Activities", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	measuring = forms.CharField(label="Dificulties", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	criteria = forms.CharField(label="Need Improvement", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalPlanningA
		fields = ['goals','measuring', 'criteria']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['measuring'].label = 'Measuring Indicator (s)'
		self.fields['criteria'].label = 'Criteria for Overcoming'
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('goals', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('measuring', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('criteria', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)
class PlanningDateForm(forms.ModelForm):
	ind_date = forms.DateField(label='Professional Behavior Date', widget=DateInput())
	class Meta:
		model = EvalPlanning
		fields = ['ind_date']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['ind_date'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('ind_date', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PlanningDate2Form(forms.ModelForm):
	obj_date = forms.DateField(label='Individual Objective Date', widget=DateInput())
	class Meta:
		model = EvalPlanning
		fields = ['obj_date']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['obj_date'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('obj_date', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)
class PlanningEvaluatorDateForm(forms.ModelForm):
	eval_date_ind = forms.DateField(label='Professional Behavior Date', widget=DateInput())
	class Meta:
		model = EvalPlanning
		fields = ['eval_date_ind']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['eval_date_ind'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('eval_date_ind', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PlanningEvaluatorDate2Form(forms.ModelForm):
	eval_date_obj = forms.DateField(label='Individual Objective Date', widget=DateInput())
	class Meta:
		model = EvalPlanning
		fields = ['eval_date_obj']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['eval_date_obj'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('eval_date_obj', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PlanningIndividualForm(forms.ModelForm):
	progress = forms.CharField(label="Progress", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	dificulties = forms.CharField(label="Dificulties", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	need_improv = forms.CharField(label="Need Improvement", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalPlanningA
		fields = ['progress','dificulties', 'need_improv']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('progress', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('dificulties', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('need_improv', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)
class PlanningBehaviorForm(forms.ModelForm):
	progress = forms.CharField(label="Progress", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	dificulties = forms.CharField(label="Dificulties", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	need_improv = forms.CharField(label="Criteria for overcoming", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalPlanningB
		fields = ['progress','dificulties', 'need_improv']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('progress', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('dificulties', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			Row(
				Column('need_improv', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PlanningObjectiveForm(forms.ModelForm):
	objective = forms.CharField(label="Objectives", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalPlanningA
		fields = ['objective']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['objective'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('objective', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)


# PRE - ASS
class PreAssIndividuoForm(forms.ModelForm):
	class Meta:
		model = EvalPreAssessmentA
		fields = ['scored']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('scored', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PreAssEvaluatorDateForm(forms.ModelForm):
	eval_ind_date = forms.DateField(label='Individual Objective Date', widget=DateInput())
	class Meta:
		model = EvalPreAssessment
		fields = ['eval_ind_date']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['eval_ind_date'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('eval_ind_date', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PreAssEvaluatorDate2Form(forms.ModelForm):
	eval_beh_date = forms.DateField(label='Professional Behavior Date', widget=DateInput())
	class Meta:
		model = EvalPreAssessment
		fields = ['eval_beh_date']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['eval_beh_date'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('eval_beh_date', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PreAssEvaluatorCommentForm(forms.ModelForm):
	comments = forms.CharField(label="Comments", required=False, widget=SummernoteWidget(attrs={'summernote': {'width': '100%', 'height': '300px'}}))
	class Meta:
		model = EvalPreAssessment
		fields = ['comments']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.fields['comments'].required = True
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('comments', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)

class PreAssBehaviorForm(forms.ModelForm):
	class Meta:
		model = EvalPreAssessmentB
		fields = ['scored']
	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('scored', css_class='form-group col-md-12 mb-0'),
				css_class='form-row'
			),
			HTML(""" <button class="btn btn-primary" type="submit" title="Rai">Rai <i class="fa fa-save"></i></button> """)
		)



# Generated by Django 3.2 on 2023-02-18 09:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0017_auto_20230218_1719'),
    ]

    operations = [
        migrations.AddField(
            model_name='eval',
            name='emp_beh_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='eval',
            name='emp_obj_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='eval',
            name='empeval_beh_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='eval',
            name='empeval_obj_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2 on 2023-02-18 07:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0013_auto_20230218_1557'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalpreassessment',
            old_name='eval_date',
            new_name='eval_ind_date',
        ),
        migrations.AddField(
            model_name='evalpreassessment',
            name='comments',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='evalpreassessment',
            name='eval_obj_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2 on 2023-02-16 09:42

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('custom', '0013_alter_unit_options'),
        ('contract', '0017_contract_file_end'),
        ('employee', '0023_alter_photo_image'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('perform', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvalChoicePlanning',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
                ('score', models.IntegerField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='EvalPlanning',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('objective', models.TextField(blank=True, null=True, verbose_name='Objectives')),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningeval', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='employee.employee')),
                ('employeeeval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningempeval', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='custom.position')),
                ('positioneval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningempeval', to='custom.position')),
                ('type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningeval', to='perform.evaltype')),
                ('unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='custom.unit')),
                ('uniteval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningempeval', to='custom.unit')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningeval', to='perform.evalyear')),
            ],
        ),
    ]



# Generated by Django 3.2 on 2023-03-10 00:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0023_rename_year_evalmonth_month'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='evaltype',
            name='month',
        ),
    ]



from django.shortcuts import render, get_object_or_404
from django.contrib.auth.decorators import login_required
from employee.models import Employee
from perform.utils import f_finalscore
from settings_app.decorators import allowed_users
from django.db.models import Sum, Count, Q
from contract.models import Category, Contract, EmpPosition
from perform.models import *
from settings_app.user_utils import c_unit

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformDash(request):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	if group == 'unit':
		cats = Category.objects.filter().exclude(Q(pk=1)|Q(pk=2)).order_by('id')
	else:
		cats = Category.objects.filter().all().order_by('id')

	objects = []
	for i in cats:
		a = Contract.objects.filter((Q(employee__curempdivision__department__unit=unit)|Q(employee__curempdivision__unit=unit)),\
			category=i, is_active=True).exclude((Q(employee__curempdivision__department__id=3)|Q(employee__curempposition__position__id=3))).all().count()
		b = Eval.objects.filter((Q(employee__curempdivision__department__unit=unit)|Q(employee__curempdivision__unit=unit)),\
			employee__contract__category=i).exclude((Q(employee__curempdivision__department__id=3)|Q(employee__curempposition__position__id=3)))\
			.all().count()
		c = a - b
		objects.append([i,a,b,c])
	context = {
		'group': group, 'objects': objects,
		'title': 'Painel Avaliasaun', 'legend': 'Painel Avaliasaun'
	}
	return render(request, 'perform2/c_eval_dash.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformList(request):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	year = EvalYear.objects.filter(is_active=True).first()
	objects = Eval.objects.filter((Q(department__unit=unit)|Q(unit=unit)),\
		year=year).exclude((Q(employee=c_emp)|Q(department__id=3)|Q(category_id=6))).all().order_by('-start_date','id')
	years = Eval.objects.filter().distinct().values('year__year').all()
	context = {
		'group': group, 'unit': unit, 'year': year, 'objects': objects, 'years': years,
		'title': f'Lista Avaliasaun Tinan {year.year}', 'legend': f'Lista Avaliasaun Tinan {year.year}'
	}
	return render(request, 'perform2/c_eval_list.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformDetail(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit, dep = "","",""
	c_emp, unit = c_unit(request.user)
	eval = get_object_or_404(Eval, hashed=hashid)
	zuri = Evaluator.objects.filter(eval=eval).first()
	evaldate = EvalDate.objects.filter(eval=eval).first()
	finalscore = EvalFinalScore.objects.filter(eval=eval).first()
	obj_as = EvalDetA.objects.filter(eval=eval).all()
	obj_bs = EvalDetB.objects.filter(eval=eval).all()
	sum_a = EvalDetA.objects.filter(eval=eval).aggregate(Sum('choice__score')).get('choice__score__sum', 0.00)
	sum_b = EvalDetB.objects.filter(eval=eval).aggregate(Sum('choice__score')).get('choice__score__sum', 0.00)
	context = {
		'group': group, 'c_emp': c_emp, 'unit': unit, 'dep': dep, 'eval': eval, 'zuri': zuri,
		'evaldate': evaldate, 'finalscore': finalscore,
		'obj_as': obj_as, 'obj_bs': obj_bs, 'sum_a': sum_a, 'sum_b': sum_b,
		'title': f'Detalha Avaliasaun', 'legend': f'Detalha Avaliasaun'
	}
	return render(request, 'perform2/c_eval_detail.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformYearList(request, year):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	year = EvalYear.objects.filter(year=year).first()
	objects = Eval.objects.filter((Q(department__unit=unit)|Q(unit=unit)),\
		year=year).exclude((Q(employee=c_emp)|Q(department__id=3)|Q(category_id=6))).all().order_by('id')
	years = Eval.objects.filter().distinct().values('year__year').all()
	context = {
		'group': group, 'unit': unit, 'year': year, 'objects': objects, 'years': years,
		'title': f'Lista Avaliasaun Tinan {year.year}', 'legend': f'Lista Avaliasaun Tinan {year.year}'
	}
	return render(request, 'perform2/c_eval_year_list.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformCatList(request, pk):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	cat = get_object_or_404(Category, pk=pk)
	year = EvalYear.objects.filter(is_active=True).first()
	objects = Eval.objects.filter((Q(department__unit=unit)|Q(unit=unit)),\
		category=cat,year=year).exclude((Q(employee=c_emp)|Q(department__id=3)|Q(category_id=6))).all().order_by('-start_date','id')
	context = {
		'group': group, 'unit': unit, 'year': year, 'cat': cat, 'objects': objects,
		'title': f'Lista Avaliasaun Tinan {year.year}', 'legend': f'Lista Avaliasaun Tinan {year.year}'
	}
	return render(request, 'perform2/c_eval_cat_list.html', context)

###


# Generated by Django 3.2 on 2023-03-10 00:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0022_auto_20230310_0923'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalmonth',
            old_name='year',
            new_name='month',
        ),
    ]



# Generated by Django 3.2 on 2023-02-17 02:16

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('employee', '0023_alter_photo_image'),
        ('contract', '0017_contract_file_end'),
        ('custom', '0013_alter_unit_options'),
        ('perform', '0007_auto_20230217_0014'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvalPreAssessment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('objective', models.TextField(blank=True, null=True, verbose_name='Objectives')),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreass', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='employee.employee')),
                ('employeeeval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassempeval', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='custom.position')),
                ('positioneval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassempeval', to='custom.position')),
                ('type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreass', to='perform.evaltype')),
                ('unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='custom.unit')),
                ('uniteval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassempeval', to='custom.unit')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreass', to='perform.evalyear')),
            ],
        ),
        migrations.CreateModel(
            name='EvalPreAssessmentB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('scored', models.CharField(blank=True, choices=[('one', 'Demonstrated Competence at a High Level (Explain)'), ('two', 'Goal Achived'), ('three', 'Goal not Reached')], max_length=100, null=True)),
                ('enter_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassb', to='perform.evalpreassessment')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassbobjective', to='perform.evalplanningb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('usereval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassbuser', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalPreAssessmentA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('scored', models.CharField(blank=True, choices=[('one', 'Goal Exceeded (Explain)'), ('two', 'Goal Achived (Explain)'), ('three', 'Goal not Reached (Explain)')], max_length=100, null=True)),
                ('enter_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassa', to='perform.evalpreassessment')),
                ('plan_objective', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassaobjective', to='perform.evalplanninga')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('usereval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassauser', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



# Generated by Django 3.2 on 2023-02-16 14:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0004_evalplanninga_eval_date'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanninga',
            name='enter_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



from django.shortcuts import render, get_object_or_404
from django.contrib.auth.decorators import login_required
from employee.models import Employee
from perform.utils import f_finalscore
from settings_app.decorators import allowed_users
from django.db.models import Sum, Count, Q
from contract.models import Category, Contract
from perform.models import *
from settings_app.user_utils import c_unit, c_staff
from custom.models import Unit

@login_required
@allowed_users(allowed_roles=['hr','de','deputy', 'unit'])
def allPerformDash(request):
	group = request.user.groups.all()[0].name
	unit = Unit.objects.all()
	emp, unit_g = c_unit(request.user)
	employee = []
	if group == 'de':
		emp = Employee.objects.filter(
			(Q(curempdivision__department__unit=unit_g)|Q(curempdivision__unit=unit_g))| \
			(Q(empposition__is_manager=True, empposition__is_active=True, empposition__unit__isnull=False))|\
			(Q(empposition__is_active=True, empposition__position__id=2))
			).select_related('curempdivision').exclude((Q(id=emp.id))).distinct()
	else:
		emp = Employee.objects.filter(
				(Q(curempdivision__department__unit=unit_g)|Q(curempdivision__unit=unit_g))
			).select_related('curempdivision').exclude((Q(id=emp.id))).distinct()

	for i in emp:
		planning = EvalPlanning.objects.filter(employee=i, year__is_active=True).last()
		preass = EvalPreAssessment.objects.filter(employee=i, year__is_active=True).last()
		selfass = EvalSelf.objects.filter(employee=i, year__is_active=True).last()
		eval = Eval.objects.filter(employee=i, year__is_active=True).last()
		employee.append([i, planning, preass, selfass, eval])
	objects = []
	for i in unit:
		objects.append(i)
	context = {
		'group': group, 'objects': objects, 'employee':employee,
		'title': 'Painel Avaliasaun', 'legend': 'Painel Avaliasaun'
	}
	return render(request, 'perform2/all_eval_dash.html', context)

@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def allPerformList(request):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	year = EvalYear.objects.filter(is_active=True).first()
	objects = Eval.objects.filter(year=year).exclude().all().order_by('-start_date','id')
	years = Eval.objects.filter().distinct().values('year__year').all()
	context = {
		'group': group, 'unit': unit, 'year': year, 'objects': objects, 'years': years,
		'title': f'Lista Avaliasaun Tinan {year.year}', 'legend': f'Lista Avaliasaun Tinan {year.year}'
	}
	return render(request, 'perform2/all_eval_list.html', context)

@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def allPerformDetail(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit, dep = "","",""
	c_emp, unit = c_unit(request.user)
	eval = get_object_or_404(Eval, hashed=hashid)
	zuri = Evaluator.objects.filter(eval=eval).first()
	evaldate = EvalDate.objects.filter(eval=eval).first()
	obj_as = EvalDetA.objects.filter(eval=eval).all()
	obj_bs = EvalDetB.objects.filter(eval=eval).all()
	sum_a = EvalDetA.objects.filter(eval=eval).aggregate(Sum('choice__score')).get('choice__score__sum', 0.00)
	sum_b = EvalDetB.objects.filter(eval=eval).aggregate(Sum('choice__score')).get('choice__score__sum', 0.00)
	context = {
		'group': group, 'c_emp': c_emp, 'unit': unit, 'dep': dep, 'eval': eval, 'zuri': zuri,
		'evaldate': evaldate,
		'obj_as': obj_as, 'obj_bs': obj_bs, 'sum_a': sum_a, 'sum_b': sum_b,
		'title': f'Detalha Avaliasaun', 'legend': f'Detalha Avaliasaun'
	}
	return render(request, 'perform2/all_eval_detail.html', context)

@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def allPerformYearList(request, year):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	year = EvalYear.objects.filter(year=year).first()
	objects = Eval.objects.filter((Q(department__unit=unit)|Q(unit=unit)),\
		year=year).exclude((Q(employee=c_emp)|Q(department__id=3)|Q(category_id=6))).all().order_by('-start_date','id')
	years = Eval.objects.filter().distinct().values('year__year').all()
	context = {
		'group': group, 'unit': unit, 'year': year, 'objects': objects, 'years': years,
		'title': f'Lista Avaliasaun Tinan {year.year}', 'legend': f'Lista Avaliasaun Tinan {year.year}'
	}
	return render(request, 'perform2/all_eval_year_list.html', context)

@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def allPerformCatList(request, pk):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	cat = get_object_or_404(Category, pk=pk)
	year = EvalYear.objects.filter(is_active=True).first()
	objects = Eval.objects.filter((Q(department__unit=unit)|Q(unit=unit)),\
		category=cat,year=year).exclude((Q(employee=c_emp)|Q(department__id=3)|Q(category_id=6))).all().order_by('-start_date','id')
	context = {
		'group': group, 'unit': unit, 'year': year, 'cat': cat, 'objects': objects,
		'title': f'Lista Avaliasaun Tinan {year.year}', 'legend': f'Lista Avaliasaun Tinan {year.year}'
	}
	return render(request, 'perform2/all_eval_cat_list.html', context)



@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def allPerformCatEvalList(request, pk):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	cat = get_object_or_404(Category, pk=pk)
	year = EvalYear.objects.filter(is_active=True).first()
	objects2 = Eval.objects.filter((Q(department__unit=unit)|Q(unit=unit)),\
		category=cat,year=year).exclude((Q(employee=c_emp)|Q(department__id=3)|Q(category_id=6))).all().order_by('-start_date','id')
	objects = Eval.objects.filter(employee__contract__category=cat).exclude().all()
	context = {
		'group': group, 'unit': unit, 'year': year, 'cat': cat, 'objects': objects,
		'title': f'Lista Funsionario nebe halo Avaliasaun', 'legend': f'Lista Funsionario nebe halo Avaliasaun'
	}
	return render(request, 'perform2/all_eval_cat_list.html', context)


@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def allPerformCatNotList(request, pk):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	cat = get_object_or_404(Category, pk=pk)
	year = EvalYear.objects.filter(is_active=True).first()
	objects2 = Eval.objects.filter((Q(department__unit=unit)|Q(unit=unit)),\
		category=cat,year=year).exclude((Q(employee=c_emp)|Q(department__id=3)|Q(category_id=6))).all().order_by('-start_date','id')
	objects = Contract.objects.filter(category=cat, is_active=True).all()
	context = {
		'group': group, 'unit': unit, 'year': year, 'cat': cat, 'objects': objects,
		'title': f'Lista Funsionario nebe seidauk halo Avaliasaun', 'legend': f'Lista Funsionario nebe seidauk halo Avaliasaun'
	}
	return render(request, 'perform2/all_eval_cat_list.html', context)



###


# Generated by Django 3.2 on 2023-03-10 10:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0024_remove_evaltype_month'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanning',
            name='month',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]



import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision
from contract.models import Contract, EmpPosition
from perform.models import EvalYear, Eval, Evaluator, EvalFinalScore, EvalSelf, EvalType, EvalSelfDetA, EvalSelfDetB, EvalPlanningA, EvalPlanningB
from perform.forms import *
from settings_app.utils import getnewid
from settings_app.user_utils import c_staff, c_dep, c_unit
from log.utils import log_action


@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformAdd(request, page):
	group = request.user.groups.all()[0].name
	if group == "staff": c_emp = c_staff(request.user)
	elif group == "dep": c_emp, _ = c_dep(request.user)
	elif group == "unit": c_emp, _ = c_unit(request.user)
	elif group == "hr": c_emp, _ = c_unit(request.user)
	year = EvalYear.objects.filter(is_active=True).first()
	contract = Contract.objects.filter(employee=c_emp).first()
	empdiv = CurEmpDivision.objects.get(employee=c_emp)
	if request.method == 'POST':
		newid, new_hashid = getnewid(EvalSelf)
		form = EvalSelfForm(request.POST)
		if form.is_valid():
			check = Eval.objects.filter(employee=c_emp, year=year).first()
			if check:
				messages.error(request, f'Dadus iha ona.')
				return redirect('eval-self-list')
			instance = form.save(commit=False)
			instance.id = newid
			instance.employee = c_emp
			instance.year = year
			instance.category = contract.category
			instance.position = contract.position
			if empdiv.department: instance.department = empdiv.department
			elif empdiv.unit: instance.unit = empdiv.unit
			instance.datetime = datetime.datetime.now()
			instance.user = request.user
			instance.hashed = new_hashid
			instance.save()
			messages.success(request, f'Aumeta sucessu.')
			return redirect('eval-self-detail', hashid=new_hashid)
	else: form = EvalSelfForm()
	context = {
		'group': group, 'form': form, 'page': 'list',
		'title': 'Prenche Avaliasaun', 'legend': 'Prenche Avaliasaun'
	}
	return render(request, 'perform2_self/form.html', context)

@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformUpdate(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(EvalSelf, hashed=hashid)
	if request.method == 'POST':
		form = EvalSelfForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.save()
			messages.success(request, f'Altera sucessu.')
			return redirect('eval-self-detail', hashid=hashid)
	else: form = EvalSelfForm(instance=objects)
	context = {
		'group': group, 'eval': objects, 'form': form, 'page': 'det',
		'title': 'Prenche Avaliasaun', 'legend': 'Prenche Avaliasaun'
	}
	return render(request, 'perform2_self/form.html', context)

@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformComUpdate(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(EvalSelf, hashed=hashid)
	if request.method == 'POST':
		form = EvalSelfForm2(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.save()
			messages.success(request, f'Altera sucessu.')
			return redirect('eval-self-detail', hashid=hashid)
	else: form = EvalSelfForm2(instance=objects)
	context = {
		'group': group, 'eval': objects, 'form': form, 'page': 'det',
		'title': 'Hadia Komentariu', 'legend': 'Hadia Komentariu'
	}
	return render(request, 'perform2_self/form.html', context)

@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformRemove(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(EvalSelf, hashed=hashid)
	objects.delete()
	messages.success(request, f'Hapaga sucessu.')
	return redirect('eval-self-list')

@login_required
def selfPerformLock(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(EvalSelf, hashed=hashid)
	if objects.ind_date != None and objects.beh_date != None:
		objects.is_lock = True
		objects.save()
		messages.success(request, f'Susesu Chave')
		if group == 'hr':
			return redirect('hr-eval-self-detail', hashid=hashid)
		else:
			return redirect('staff-perform-self-detail', hashid=hashid)
	else:
		messages.error(request, f'Data Seidauk Prienche')
		if group == 'hr':
			return redirect('hr-eval-self-detail', hashid=hashid)
		else:
			return redirect('staff-perform-self-detail', hashid=hashid)


@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformUnlock(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(EvalSelf, hashed=hashid)
	objects.is_lock = False
	objects.save()
	messages.success(request, f'Loke.')
	return redirect('eval-self-detail', hashid=hashid)

@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformFinish(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(EvalSelf, hashed=hashid)
	objects.is_finish = True
	objects.save()
	messages.success(request, f'Termina.')
	return redirect('eval-self-detail', hashid=hashid)
### NEW

@login_required
def PerfomConfAddSelfEval(request, hashid, year):
	group = request.user.groups.all()[0].name
	employee = get_object_or_404(Employee, hashed=hashid)
	pyear = get_object_or_404(EvalYear, year=year)
	ptype = get_object_or_404(EvalType, pk=3)
	contract = Contract.objects.filter(employee=employee, is_active=True).last()
	empdiv = CurEmpDivision.objects.filter(employee=employee).last()
	newid, new_hashid = getnewid(EvalSelf)
	obj = EvalSelf(
		id = newid,
		hashed= new_hashid,
		year = pyear,
		type = ptype,
		employee = employee,
		category = contract.category,
		position = contract.position,
		department = empdiv.department,
		unit = empdiv.unit
	)
	obj.save()
	objects = EvalPlanningA.objects.filter(eval__employee=employee, eval__year__year=year).all()
	objects2 = EvalPlanningB.objects.filter(eval__employee=employee, eval__year__year=year).all()
	
	
	for i in objects:
		newid2, new_hashid2 = getnewid(EvalSelfDetA)
		obj2 = EvalSelfDetA(id=newid2, eval=obj, parameter=i,\
			user=request.user, hashed=new_hashid2)
		obj2.save()
	for j in objects2:
		newid3, new_hashid3 = getnewid(EvalSelfDetB)
		obj3 = EvalSelfDetB(id=newid3, eval=obj, parameter=j,\
			user=request.user, hashed=new_hashid3)
		obj3.save()
	messages.success(request, 'Susesu Kria Self Evaluation Sheet')
	if group == 'hr':
		return redirect('eval-conf-dash')
	else:
		return redirect('staff-perform-list')


@login_required
def selfPerformDetAUpdate(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(EvalSelfDetA, hashed=hashid)
	if request.method == 'POST':
		form = EvalSelfDetAForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			log_action(request, model='self_evaluation_ind_objective', action="Update",field_id=objects.pk)
			messages.success(request, f'Altera sucessu.')
			if group == 'hr':
				return redirect('hr-eval-self-detail', hashid=objects.eval.hashed)
			else:
				return redirect('staff-perform-self-detail', hashid=objects.eval.hashed)

	else: form = EvalSelfDetAForm(instance=objects)
	context = {
		'group': group,  'form': form, 
		'objects':objects, 'page': 'self-a',
		'title': 'Aumenta Self Evaluation Individual Objectives',
		'legend': 'Aumenta Self Evaluation Individual Objectives'
	}
	return render(request, 'perform2/form_det.html', context)

@login_required
def selfPerformDetBUpdate(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(EvalSelfDetB, hashed=hashid)
	if request.method == 'POST':
		form = EvalSelfDetBForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			log_action(request, model='self_evaluation_prof_behavior', action="Update",field_id=objects.pk)
			messages.success(request, f'Altera sucessu.')
			if group == 'hr':
				return redirect('hr-eval-self-detail', hashid=objects.eval.hashed)
			else:
				return redirect('staff-perform-self-detail', hashid=objects.eval.hashed)
	else: form = EvalSelfDetBForm(instance=objects)
	context = {
		'group': group,  'form': form, 
		'objects':objects, 'page': 'self-b',
		'title': 'Aumenta Self Evaluation Professional Objective',
		'legend': 'Aumenta Self Evaluation Professional Objective'
	}
	return render(request, 'perform2/form_det.html', context)


@login_required
def SelfEvalAddObjDate(request, hashid):
	objects = get_object_or_404(EvalSelf,hashed=hashid)
	group = request.user.groups.all()[0].name
	if request.method == 'POST':
			form = SelfDateForm(request.POST, instance=objects)

			if form.is_valid():
				form.save()
			messages.success(request, f'Aumeta Sucessu')
			if group == 'hr':
				return redirect('hr-eval-self-detail', objects.hashed)
			else:
				return redirect('staff-perform-self-detail', objects.hashed)

	else: form = SelfDateForm(instance=objects)
	context = {
		'group': group, 'form': form, 'page': 'unit', 
		'objects':objects, 'page2': 'self',
		'title': 'Aumenta Data', 'legend': 'Aumenta Data'
	}
	return render(request, 'perform2/form.html', context)

@login_required
def SelfEvalAddBehDate(request, hashid):
	objects = get_object_or_404(EvalSelf,hashed=hashid)
	group = request.user.groups.all()[0].name
	if request.method == 'POST':
			form = SelfDate2Form(request.POST, instance=objects)

			if form.is_valid():
				form.save()
			messages.success(request, f'Aumeta Sucessu')
			if group == 'hr':
				return redirect('hr-eval-self-detail', objects.hashed)
			else:
				return redirect('staff-perform-self-detail', objects.hashed)
	else: form = SelfDate2Form(instance=objects)
	context = {
		'group': group, 'form': form, 'page': 'unit',
		'objects':objects,  'page2': 'self',
		'title': 'Aumenta Data', 'legend': 'Aumenta Data'
	}
	return render(request, 'perform2/form.html', context)

@login_required
def SelfEvalAddComment(request, hashid):
	objects = get_object_or_404(EvalSelf,hashed=hashid)
	group = request.user.groups.all()[0].name
	if request.method == 'POST':
			form = SelfCommentForm(request.POST, instance=objects)

			if form.is_valid():
				form.save()
			messages.success(request, f'Aumeta Sucessu')
			if group == 'hr':
					return redirect('hr-eval-self-detail', objects.hashed)
			else:
				return redirect('staff-perform-self-detail', objects.hashed)
	else: form = SelfCommentForm(instance=objects)
	context = {
		'group': group, 'form': form, 'page': 'unit', 'objects':objects, 
		'title': 'Aumenta Komentario', 'legend': 'Aumenta Komentario', 'page2': 'self',
	}
	return render(request, 'perform2/form.html', context)